@@ -567,6 +567,7 @@ impl Command for List {
         }
 
         if let Some(group_by) = self.group_by {
+            command.add_argument("group").unwrap();
             command.add_argument(group_by).unwrap();
         }
 
@@ -1055,6 +1056,33 @@ mod tests {
         );
     }
 
+    #[test]
+    fn command_list() {
+        assert_eq!(
+            List::new(Tag::Album).into_command(),
+            RawCommand::new("list").argument("Album")
+        );
+
+        let filter = Filter::tag(Tag::Artist, "Foo");
+        assert_eq!(
+            List::new(Tag::Album).filter(filter.clone()).into_command(),
+            RawCommand::new("list").argument("Album").argument(filter)
+        );
+
+        let filter = Filter::tag(Tag::Artist, "Foo");
+        assert_eq!(
+            List::new(Tag::Album)
+                .filter(filter.clone())
+                .group_by(Tag::AlbumArtist)
+                .into_command(),
+            RawCommand::new("list")
+                .argument("Album")
+                .argument(filter)
+                .argument("group")
+                .argument("AlbumArtist")
+        );
+    }
+
     #[test]
     fn command_listallinfo() {
         assert_eq!(
