@@ -1,5 +1,3 @@
-use std::convert::TryFrom;
-
 use super::KeyValuePair;
 use crate::tag::Tag;
 
@@ -7,6 +5,7 @@ use crate::tag::Tag;
 ///
 /// [`list`]: crate::commands::definitions::List
 #[derive(Clone, Debug, PartialEq, Eq)]
+#[non_exhaustive]
 pub struct List {
     /// The fields returned by the command, in the order returned by MPD.
     pub fields: Vec<(Tag, String)>,
